@@ -1,6 +1,5 @@
 package KelpX::Symbiosis::Engine;
-$KelpX::Symbiosis::Engine::VERSION = '2.00_02'; # TRIAL
-$KelpX::Symbiosis::Engine::VERSION = '2.0002';
+$KelpX::Symbiosis::Engine::VERSION = '2.10';
 use Kelp::Base;
 use Carp;
 use Scalar::Util qw(blessed refaddr);
@@ -72,7 +71,7 @@ them.
 
 =head3 adapter
 
-An instance of L<KelpX::Symbiosis::Adapter>.
+An instance of C<KelpX::Symbiosis::Adapter>.
 
 =head3 app_runners
 
